<?php

/**
 * @file
 * Contains admin page related functions.
 */

/**
 * Page callback for the module settings page.
 */
function material_scrolltop_settings_page() {
  $form = [];

  $states_common = [
    '#states' => [
      'disabled' => [
        ':input[name="material_scrolltop_s_enabled"]' => ['checked' => FALSE],
      ],
    ],
  ];

  $form['material_scrolltop_enabled'] = [
    '#type' => 'checkbox',
    '#title' => t('Enable Material ScrollTop Button'),
    '#default_value' => _material_scrolltop_get_variable('material_scrolltop_enabled'),
  ];

  $form['material_scrolltop_s_enabled'] = [
    '#type' => 'checkbox',
    '#title' => t('Use the following custom settings'),
    '#default_value' => _material_scrolltop_get_variable('material_scrolltop_s_enabled'),
  ];

  // revealElement
  $form['material_scrolltop_s_revealElement'] = [
    '#type' => 'textfield',
    // This is better left untranslated.
    '#title' => 'revealElement',
    '#default_value' => _material_scrolltop_get_variable('material_scrolltop_s_revealElement'),
    '#description' => t('Reveal button when scrolling over specific element (default value: %default)', [
      '%default' => 'body',
    ]),
  ] + $states_common;

  // revealPosition
  $form['material_scrolltop_s_revealPosition'] = [
    '#type' => 'select',
    // This is better left untranslated.
    '#title' => 'revealPosition',
    '#default_value' => _material_scrolltop_get_variable('material_scrolltop_s_revealPosition'),
    '#options' => [
      'top' => 'top',
      'bottom' => 'bottom',
    ],
    '#description' => t("Element position for reveal button ('top' or 'bottom') (default value: %default)", [
      '%default' => 'top',
    ]),
  ] + $states_common;

  // duration
  // padding
  $form['material_scrolltop_s_padding'] = [
    '#type' => 'textfield',
    // This is better left untranslated.
    '#title' => 'padding',
    '#default_value' => _material_scrolltop_get_variable('material_scrolltop_s_padding'),
    '#description' => t('Adjusts little ups and downs in scrolling (can be negative number) (default value: %default)', [
      '%default' => 0,
    ]),
    '#element_validate' => ['element_validate_integer'],
  ] + $states_common;

  // duration
  $form['material_scrolltop_s_duration'] = [
    '#type' => 'textfield',
    // This is better left untranslated.
    '#title' => 'duration',
    '#default_value' => _material_scrolltop_get_variable('material_scrolltop_s_duration'),
    '#description' => t('Determining how long the animation will run (default value: %default)', [
      '%default' => 600,
    ]),
    '#element_validate' => ['element_validate_integer_positive'],
  ] + $states_common;

  // easing
  $form['material_scrolltop_s_easing'] = [
    '#type' => 'select',
    // This is better left untranslated.
    '#title' => 'easing',
    '#default_value' => _material_scrolltop_get_variable('material_scrolltop_s_easing', 'swing'),
    '#options' => [
      'swing' => 'swing',
      'linear' => 'linear',
    ],
    '#description' => t('Indicating which easing function to use for the transition animate() (default value: %default)', [
      '%default' => 'swing',
    ]),
  ] + $states_common;

  return system_settings_form($form);
}
